@@ -2,6 +2,7 @@ QT_TRANSLATE_NOOP("JMdictLongDescs", "martial arts term");
 QT_TRANSLATE_NOOP("JMdictLongDescs", "rude or X-rated term (not displayed in educational software)");
 QT_TRANSLATE_NOOP("JMdictLongDescs", "abbreviation");
 QT_TRANSLATE_NOOP("JMdictLongDescs", "adjective (keiyoushi)");
+QT_TRANSLATE_NOOP("JMdictLongDescs", "adjective (keiyoushi) - yoi/ii class");
 QT_TRANSLATE_NOOP("JMdictLongDescs", "adjectival nouns or quasi-adjectives (keiyodoshi)");
 QT_TRANSLATE_NOOP("JMdictLongDescs", "nouns which may take the genitive case particle `no'");
 QT_TRANSLATE_NOOP("JMdictLongDescs", "pre-noun adjectival (rentaishi)");
@@ -20,11 +21,12 @@ QT_TRANSLATE_NOOP("JMdictLongDescs", "children's language");
 QT_TRANSLATE_NOOP("JMdictLongDescs", "colloquialism");
 QT_TRANSLATE_NOOP("JMdictLongDescs", "computer terminology");
 QT_TRANSLATE_NOOP("JMdictLongDescs", "conjunction");
+QT_TRANSLATE_NOOP("JMdictLongDescs", "copula");
 QT_TRANSLATE_NOOP("JMdictLongDescs", "counter");
 QT_TRANSLATE_NOOP("JMdictLongDescs", "derogatory");
 QT_TRANSLATE_NOOP("JMdictLongDescs", "exclusively kanji");
 QT_TRANSLATE_NOOP("JMdictLongDescs", "exclusively kana");
-QT_TRANSLATE_NOOP("JMdictLongDescs", "Expressions (phrases, clauses, etc.)");
+QT_TRANSLATE_NOOP("JMdictLongDescs", "expressions (phrases, clauses, etc.)");
 QT_TRANSLATE_NOOP("JMdictLongDescs", "familiar language");
 QT_TRANSLATE_NOOP("JMdictLongDescs", "female term or language");
 QT_TRANSLATE_NOOP("JMdictLongDescs", "food term");
@@ -69,7 +71,10 @@ QT_TRANSLATE_NOOP("JMdictLongDescs", "slang");
 QT_TRANSLATE_NOOP("JMdictLongDescs", "suffix");
 QT_TRANSLATE_NOOP("JMdictLongDescs", "word usually written using kanji alone");
 QT_TRANSLATE_NOOP("JMdictLongDescs", "word usually written using kana alone");
+QT_TRANSLATE_NOOP("JMdictLongDescs", "unclassified");
+QT_TRANSLATE_NOOP("JMdictLongDescs", "yojijukugo");
 QT_TRANSLATE_NOOP("JMdictLongDescs", "Ichidan verb");
+QT_TRANSLATE_NOOP("JMdictLongDescs", "Ichidan verb - kureru special class");
 QT_TRANSLATE_NOOP("JMdictLongDescs", "Nidan verb with 'u' ending (archaic)");
 QT_TRANSLATE_NOOP("JMdictLongDescs", "Yodan verb with `hu/fu' ending (archaic)");
 QT_TRANSLATE_NOOP("JMdictLongDescs", "Yodan verb with `ru' ending (archaic)");
@@ -155,9 +160,11 @@ QT_TRANSLATE_NOOP("JMdictLongDescs", "engineering term");
 QT_TRANSLATE_NOOP("JMdictLongDescs", "finance term");
 QT_TRANSLATE_NOOP("JMdictLongDescs", "geology, etc. term");
 QT_TRANSLATE_NOOP("JMdictLongDescs", "law, etc. term");
+QT_TRANSLATE_NOOP("JMdictLongDescs", "mahjong term");
 QT_TRANSLATE_NOOP("JMdictLongDescs", "medicine, etc. term");
 QT_TRANSLATE_NOOP("JMdictLongDescs", "music term");
 QT_TRANSLATE_NOOP("JMdictLongDescs", "Shinto term");
+QT_TRANSLATE_NOOP("JMdictLongDescs", "shogi term");
 QT_TRANSLATE_NOOP("JMdictLongDescs", "sports term");
 QT_TRANSLATE_NOOP("JMdictLongDescs", "sumo term");
 QT_TRANSLATE_NOOP("JMdictLongDescs", "zoology term");
