@@ -93,18 +93,21 @@ static const QMap<QString, QString> _langMapping()
 	QMap<QString, QString> ret;
 	ret.insert("ar", QT_TRANSLATE_NOOP("GeneralPreferences", "Arabic"));
 	ret.insert("cs", QT_TRANSLATE_NOOP("GeneralPreferences", "Czech"));
-	ret.insert("nl", QT_TRANSLATE_NOOP("GeneralPreferences", "Dutch"));
-	ret.insert("fi_FI", QT_TRANSLATE_NOOP("GeneralPreferences", "Finnish (Finland)"));
-	ret.insert("en", QT_TRANSLATE_NOOP("GeneralPreferences", "English"));
-	ret.insert("fr", QT_TRANSLATE_NOOP("GeneralPreferences", "French"));
 	ret.insert("de", QT_TRANSLATE_NOOP("GeneralPreferences", "German"));
+	ret.insert("en", QT_TRANSLATE_NOOP("GeneralPreferences", "English"));
+	ret.insert("es", QT_TRANSLATE_NOOP("GeneralPreferences", "Spanish"));
+	ret.insert("fa_IR", QT_TRANSLATE_NOOP("GeneralPreferences", "Persian (Iran)"));
+	ret.insert("fi_FI", QT_TRANSLATE_NOOP("GeneralPreferences", "Finnish (Finland)"));
+	ret.insert("fr", QT_TRANSLATE_NOOP("GeneralPreferences", "French"));
+	ret.insert("hu", QT_TRANSLATE_NOOP("GeneralPreferences", "Hungarian"));
+	ret.insert("id", QT_TRANSLATE_NOOP("GeneralPreferences", "Indonesian"));
 	ret.insert("it", QT_TRANSLATE_NOOP("GeneralPreferences", "Italian"));
 	ret.insert("ja", QT_TRANSLATE_NOOP("GeneralPreferences", "Japanese"));
 	ret.insert("nb", QT_TRANSLATE_NOOP("GeneralPreferences", "Norvegian Bokmal"));
+	ret.insert("nl", QT_TRANSLATE_NOOP("GeneralPreferences", "Dutch"));
 	ret.insert("pl", QT_TRANSLATE_NOOP("GeneralPreferences", "Polish"));
 	ret.insert("pt", QT_TRANSLATE_NOOP("GeneralPreferences", "Portuguese"));
 	ret.insert("ru", QT_TRANSLATE_NOOP("GeneralPreferences", "Russian"));
-	ret.insert("es", QT_TRANSLATE_NOOP("GeneralPreferences", "Spanish"));
 	ret.insert("sv", QT_TRANSLATE_NOOP("GeneralPreferences", "Swedish"));
 	ret.insert("th", QT_TRANSLATE_NOOP("GeneralPreferences", "Thai"));
 	ret.insert("tr", QT_TRANSLATE_NOOP("GeneralPreferences", "Turkish"));
