@@ -178,10 +178,16 @@ void checkUserProfileDirectory()
 
 int main(int argc, char *argv[])
 {
+	extern void qt_set_sequence_auto_mnemonic(bool b);
+
 	// Seed the random number generator
 	qsrand(QDateTime::currentDateTime().toTime_t());
 	QApplication app(argc, argv);
 
+	// Enable auto-mnemonics for Mac OS X. Ideally this would only
+	// be called on Mac OS X.
+	qt_set_sequence_auto_mnemonic(true);
+
 	QCoreApplication::setOrganizationDomain(__ORGANIZATION_NAME);
 	QCoreApplication::setApplicationName(__APPLICATION_NAME);
 	QCoreApplication::setApplicationVersion(VERSION);
